==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/el.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Μη διαθέσιμος αποθηκευτικός χώρος",
    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Unknown error" : "Άγνωστο σφάλμα",
    "Could not move %s - File with this name already exists" : "Αδυναμία μετακίνησης του %s - υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move %s" : "Αδυναμία μετακίνησης του %s",
    "Permission denied" : "Η πρόσβαση απορρίφθηκε",
    "The target folder has been moved or deleted." : "Ο φάκελος προορισμού έχει μετακινηθεί ή διαγραφεί.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Το όνομα %s χρησιμοποιείτε ήδη στον φάκελο %s. Παρακαλώ επιλέξτε ένα άλλο όνομα.",
    "Error when creating the file" : "Σφάλμα κατά τη δημιουργία του αρχείου",
    "Error when creating the folder" : "Σφάλμα δημιουργίας φακέλου",
    "Unable to set upload directory." : "Αδυναμία ορισμού καταλόγου αποστολής.",
    "Invalid Token" : "Μη έγκυρο Token",
    "No file was uploaded. Unknown error" : "Δεν ανέβηκε κάποιο αρχείο. Άγνωστο σφάλμα",
    "There is no error, the file uploaded with success" : "Δεν υπάρχει σφάλμα, το αρχείο εστάλει επιτυχώς",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Το αρχείο που εστάλει υπερβαίνει την οδηγία μέγιστου επιτρεπτού μεγέθους \"upload_max_filesize\" του php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το ανεβασμένο αρχείο υπερβαίνει το MAX_FILE_SIZE που ορίζεται στην  HTML φόρμα",
    "The uploaded file was only partially uploaded" : "Το αρχείο εστάλει μόνο εν μέρει",
    "No file was uploaded" : "Κανένα αρχείο δεν στάλθηκε",
    "Missing a temporary folder" : "Λείπει ο προσωρινός φάκελος",
    "Failed to write to disk" : "Αποτυχία εγγραφής στο δίσκο",
    "Not enough storage available" : "Μη επαρκής διαθέσιμος αποθηκευτικός χώρος",
    "Upload failed. Could not find uploaded file" : "Η φόρτωση απέτυχε. Αδυναμία εύρεσης αρχείου προς φόρτωση.",
    "Upload failed. Could not get file info." : "Η φόρτωση απέτυχε. Αδυναμία λήψης πληροφοριών αρχείων.",
    "Invalid directory." : "Μη έγκυρος φάκελος.",
    "Files" : "Αρχεία",
    "All files" : "Όλα τα αρχεία",
    "Favorites" : "Αγαπημένες",
    "Home" : "Σπίτι",
    "Close" : "Κλείσιμο",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος αρχείων ή έχει 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Το συνολικό μέγεθος αρχείου {size1} υπερβαίνει το όριο μεταφόρτωσης {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνετε μέγεθος {size1} αλλά υπάρχει χώρος μόνο {size2}",
    "Upload cancelled." : "Η αποστολή ακυρώθηκε.",
    "Could not get result from server." : "Αδυναμία λήψης αποτελέσματος από το διακομιστή.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Η αποστολή του αρχείου βρίσκεται σε εξέλιξη. Το κλείσιμο της σελίδας θα ακυρώσει την αποστολή.",
    "Actions" : "Ενέργειες",
    "Download" : "Λήψη",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Details" : "Λεπτομέρειες",
    "Select" : "Επιλογή",
    "Pending" : "Εκκρεμεί",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας ",
    "This operation is forbidden" : "Αυτή η ενέργεια απαγορεύεται",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλώ ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Error moving file." : "Σφάλμα κατά τη μετακίνηση του αρχείου.",
    "Error moving file" : "Σφάλμα κατά τη μετακίνηση του αρχείου",
    "Error" : "Σφάλμα",
    "{new_name} already exists" : "{new_name} υπάρχει ήδη",
    "Could not rename file" : "Αδυναμία μετονομασίας αρχείου",
    "Could not create file" : "Αδυναμία δημιουργίας αρχείου",
    "Could not create folder" : "Αδυναμία δημιουργίας φακέλου",
    "Error deleting file." : "Σφάλμα διαγραφής αρχείου.",
    "No entries in this folder match '{filter}'" : "Δεν ταιριάζουν καταχωρήσεις σε αυτόν το φάκελο '{filter}'",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "{dirs} and {files}" : "{Κατάλογοι αρχείων} και {αρχεία}",
    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα φόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Ανέβασμα %n αρχείου","Ανέβασμα %n αρχείων"],
    "New" : "Νέο",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" είναι μη έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του {owner} είναι πλήρης, τα αρχεία δεν δύναται να ενημερωθούν ή να συγχρονίσουν!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πια!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν πλήρης ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ταιριάζουν '{filter}' ","ταιριάζουν '{filter}'"],
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Προτιμώμενα",
    "Favorite" : "Αγαπημένο",
    "{newname} already exists" : "το {newname} υπάρχει ήδη",
    "Upload" : "Μεταφόρτωση",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt",
    "Folder" : "Φάκελος",
    "New folder" : "Νέος κατάλογος",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "A new file or folder has been <strong>created</strong>" : "Ένα νέο αρχείο ή κατάλογος έχουν <strong>δημιουργηθεί</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Βάλτε όριο στις ειδοποιήσεις για τη δημιουργία και αλλαγές στα <strong>αγαπημένα σας αρχεία</strong> <em>(Μόνο Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>διαγραφεί</strong>",
    "A file or folder has been <strong>restored</strong>" : "Ένα αρχείο ή φάκελος <strong>επαναφέρθηκε</ strong>",
    "You created %1$s" : "Δημιουργήσατε %1$s",
    "%2$s created %1$s" : "Ο %2$s δημιούργησε %1$s",
    "%1$s was created in a public folder" : "Το %1$s δημιουργήθηκε σε έναν δημόσιο φάκελο",
    "You changed %1$s" : "Αλλάξατε %1$s",
    "%2$s changed %1$s" : "Ο %2$s άλλαξε %1$s",
    "You deleted %1$s" : "Διαγράψατε %1$s",
    "%2$s deleted %1$s" : "Ο %2$s διέγραψε %1$s",
    "You restored %1$s" : "Επαναφέρατε %1$s",
    "%2$s restored %1$s" : "%2$s επανέφερε %1$s",
    "Changed by %2$s" : "Άλλαξε από %2$s",
    "Deleted by %2$s" : "Διαγράφηκε από %2$s",
    "Restored by %2$s" : "Επαναφορά απο %2$s",
    "%s could not be renamed as it has been deleted" : "%s δεν μπορούσε να μετονομαστεί εφόσον είχε διαγραφεί",
    "%s could not be renamed" : "Αδυναμία μετονομασίας του %s",
    "Upload (max. %s)" : "Διαμοιρασμός (max. %s)",
    "File handling" : "Διαχείριση αρχείων",
    "Maximum upload size" : "Μέγιστο μέγεθος αποστολής",
    "max. possible: " : "μέγιστο δυνατό:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Με την PHP-FPM αυτή η τιμή μπορεί να χρειαστεί μέχρι και 5 λεπτά για να ενεργοποιηθεί μετά την αποθήκευση.",
    "Save" : "Αποθήκευση",
    "Can not be edited from here due to insufficient permissions." : "Δεν υπάρχει εδώ η δυνατότητα επεξεργασίας λόγω μη επαρκών δικαιωμάτων",
    "Settings" : "Ρυθμίσεις",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Χρησιμοποιήστε αυτήν την διεύθυνση για να αποκτήσετε <a href=\"%s\" target=\"_blank\">πρόσβαση στα αρχεία σας μέσω WebDAV</a>",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "No files in here" : "Δεν υπάρχουν αρχεία",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς αποστολή",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να ανεβάσετε υπερβαίνουν το μέγιστο μέγεθος αποστολής αρχείων σε αυτόν τον διακομιστή.",
    "Files are being scanned, please wait." : "Τα αρχεία σαρώνονται, παρακαλώ περιμένετε.",
    "Currently scanning" : "Σάρωση σε εξέλιξη",
    "No favorites" : "Δεν υπάρχουν αγαπημένα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα  θα εμφανιστούν εδώ "
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/el.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Μη διαθέσιμος αποθηκευτικός χώρος",
    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Unknown error" : "Άγνωστο σφάλμα",
    "Unable to set upload directory." : "Αδυναμία ορισμού καταλόγου αποστολής.",
    "Invalid Token" : "Μη έγκυρο Token",
    "No file was uploaded. Unknown error" : "Δεν ανέβηκε κάποιο αρχείο. Άγνωστο σφάλμα",
    "There is no error, the file uploaded with success" : "Δεν υπάρχει σφάλμα, το αρχείο εστάλει επιτυχώς",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Το αρχείο που εστάλει υπερβαίνει την οδηγία μέγιστου επιτρεπτού μεγέθους \"upload_max_filesize\" του php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το ανεβασμένο αρχείο υπερβαίνει το MAX_FILE_SIZE που ορίζεται στην  HTML φόρμα",
    "The uploaded file was only partially uploaded" : "Το αρχείο εστάλει μόνο εν μέρει",
    "No file was uploaded" : "Κανένα αρχείο δεν στάλθηκε",
    "Missing a temporary folder" : "Λείπει ο προσωρινός φάκελος",
    "Failed to write to disk" : "Αποτυχία εγγραφής στο δίσκο",
    "Not enough storage available" : "Ο διαθέσιμος αποθηκευτικός χώρος δεν επαρκεί",
    "The target folder has been moved or deleted." : "Ο φάκελος προορισμού έχει μετακινηθεί ή διαγραφεί.",
    "Upload failed. Could not find uploaded file" : "Η φόρτωση απέτυχε. Αδυναμία εύρεσης αρχείου προς φόρτωση.",
    "Upload failed. Could not get file info." : "Η φόρτωση απέτυχε. Αδυναμία λήψης πληροφοριών αρχείων.",
    "Invalid directory." : "Μη έγκυρος φάκελος.",
    "Files" : "Αρχεία",
    "All files" : "Όλα τα αρχεία",
    "Favorites" : "Αγαπημένα",
    "Home" : "Σπίτι",
    "Close" : "Κλείσιμο",
    "Upload cancelled." : "Η αποστολή ακυρώθηκε.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος αρχείων ή έχει 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Το συνολικό μέγεθος αρχείου {size1} υπερβαίνει το όριο μεταφόρτωσης {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνετε μέγεθος {size1} αλλά υπάρχει χώρος μόνο {size2}",
    "Could not get result from server." : "Αδυναμία λήψης αποτελέσματος από το διακομιστή.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Η αποστολή του αρχείου βρίσκεται σε εξέλιξη. Το κλείσιμο της σελίδας θα ακυρώσει την αποστολή.",
    "Actions" : "Ενέργειες",
    "Download" : "Λήψη",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Disconnect storage" : "Αποσυνδεδεμένος αποθηκευτικός χώρος",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "Details" : "Λεπτομέρειες",
    "Select" : "Επιλογή",
    "Pending" : "Εκκρεμεί",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας ",
    "This operation is forbidden" : "Αυτή η ενέργεια δεν επιτρέπεται",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλώ ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
    "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του \"{file}\"",
    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
    "Error deleting file \"{fileName}\"." : "Αδυναμία διαγραφής του \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Δεν ταιριάζουν καταχωρήσεις σε αυτόν το φάκελο '{filter}'",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "{dirs} and {files}" : "{dirs} και {files}",
    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα φόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Ανέβασμα %n αρχείου","Ανέβασμα %n αρχείων"],
    "New" : "Νέο",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του {owner} είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ταιριάζουν '{filter}' ","ταιριάζουν '{filter}'"],
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Προτιμώμενα",
    "Favorite" : "Αγαπημένο",
    "Folder" : "Φάκελος",
    "New folder" : "Νέος φάκελος",
    "{newname} already exists" : "το {newname} υπάρχει ήδη",
    "Upload" : "Μεταφόρτωση",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "A new file or folder has been <strong>created</strong>" : "Ένα νέο αρχείο ή κατάλογος έχουν <strong>δημιουργηθεί</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Βάλτε όριο στις ειδοποιήσεις για τη δημιουργία και αλλαγές στα <strong>αγαπημένα σας αρχεία</strong> <em>(Μόνο Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>διαγραφεί</strong>",
    "A file or folder has been <strong>restored</strong>" : "Ένα αρχείο ή φάκελος <strong>επαναφέρθηκε</ strong>",
    "You created %1$s" : "Δημιουργήσατε το %1$s",
    "%2$s created %1$s" : "Ο χρήστης %2$s δημιούργησε το %1$s",
    "%1$s was created in a public folder" : "Το %1$s δημιουργήθηκε σε έναν δημόσιο φάκελο",
    "You changed %1$s" : "Αλλάξατε το %1$s",
    "%2$s changed %1$s" : "Ο χρήστης %2$s άλλαξε το %1$s",
    "You deleted %1$s" : "Διαγράψατε το %1$s",
    "%2$s deleted %1$s" : "Ο χρήστης %2$s διέγραψε το %1$s",
    "You restored %1$s" : "Επαναφέρατε το %1$s",
    "%2$s restored %1$s" : "Ο χρήστης %2$s επανέφερε το %1$s",
    "Changed by %2$s" : "Άλλαξε από το χρήστη %2$s",
    "Deleted by %2$s" : "Διαγράφηκε από το χρήστη %2$s",
    "Restored by %2$s" : "Επαναφορά από το χρήστη %2$s",
    "Upload (max. %s)" : "Διαμοιρασμός (max. %s)",
    "File handling" : "Διαχείριση αρχείων",
    "Maximum upload size" : "Μέγιστο μέγεθος αποστολής",
    "max. possible: " : "μέγιστο δυνατό:",
    "Save" : "Αποθήκευση",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Με PHP-FPM μπορεί να χρειαστούν μέχρι και 5 λεπτά για να ενεργοποιηθούν οι αλλαγές.",
    "Missing permissions to edit from here." : "Δεν υπάρχουν τα απαραίτητα δικαιώματα για να γίνει τροποποιήση σε αυτό το σημείο.",
    "Settings" : "Ρυθμίσεις",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Χρησιμοποιήστε αυτήν την διεύθυνση για να αποκτήσετε <a href=\"%s\" target=\"_blank\">πρόσβαση στα αρχεία σας μέσω WebDAV</a>",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "No files in here" : "Δεν υπάρχουν αρχεία",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς αποστολή",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να ανεβάσετε υπερβαίνουν το μέγιστο μέγεθος αποστολής αρχείων σε αυτόν τον διακομιστή.",
    "No favorites" : "Δεν υπάρχουν αγαπημένα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα  θα εμφανιστούν εδώ ",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt"
},
"nplurals=2; plural=(n != 1);");
